@@ -3,29 +3,45 @@ package GUIDeFATE;
    use strict;
    use warnings;
    
-   our $VERSION = '0.052';
+   our $VERSION = '0.06';
    
    use Exporter 'import';
    
-   our $frame;
    our @EXPORT_OK      = qw<$frame>;  # allows manipulation of frame from main.
-   
+   our $target="wx";
+   our $AppObject;
+   our $winX=30;
+   our $winY=30;
+   our $winWidth;
+   our $winHeight;
+   our $winTitle;
+   our $winScale=6.5;     
    my  $autoGen="";
    my  $log="";
 
 sub new{
-	my $class= shift;
-	my $target=shift;
-	if (!$target || ($target =~m/wx/i)){
-		 use GFwx qw<addButton addStatText addTextCtrl addMenuBits addPanel setScale $frame $winScale $winWidth $winHeight $winTitle>;
-		 return GFwx->new();
+	my ($class,$textGUI,$target,$assist)=@_;
+	if ((!$target)||($target=~/wx/i)){
+		$target="wx";
+		eval " use GFwx qw<addButton addStatText addTextCtrl addMenuBits addPanel setScale
+		           \$frame \$winScale \$winWidth \$winHeight \$winTitle>;";
+		convert($textGUI,$assist);
+		return GFwx->new(); ;
+	}
+	elsif ($target =~m/tk/i){
+		eval " use GFtk qw<addButton addStatText addTextCtrl addMenuBits addPanel setScale 
+		           \$frame \$winScale \$winWidth \$winHeight \$winTitle>;";
+		convert($textGUI, $target);
+		return GFtk->new(); 
 	}
 }
 
+
 sub convert{
-	
-	my @lines=(split /\n/ ,shift) ;
-	my $assist=shift; if (!$assist){$assist="q"};
+	my($textGUI,$assist)=@_;
+	my @lines=(split /\n/ ,$textGUI) ;
+	if (!$assist){$assist="q"};
+		           
 	my $verbose= $assist=~/v/;
 	my $debug= $assist=~/d/;
 	my $auto= $assist=~/a/;
@@ -73,11 +89,11 @@ sub convert{
 		
 		
 		while ($line =~m/(\{([^}]*)\})/g){   # buttons are made from { <label> } 
-			my $ps=length($`);
-			$log= "Button with label '". $2."' calls function &btn$bid\n"; ##
+			my $ps=length($`);my $label=$2; my $len=length ($label);$label=~s/^(\s+)|(\s+)$//g;
+			$log= "Button with label '$label' calls function &btn$bid\n"; ##
 			if ($verbose){ print $log; }
-			if ($auto){ $autoGen.=makeSub("btn$bid", "button with label $2 "); }			
-			addButton([$bid, $2,[$winScale*($ps*2-1),$winScale*$l*4],[$winScale*(length($2)*2+3),$winScale*4], \&{"main::btn".$bid++}]);
+			if ($auto){ $autoGen.=makeSub("btn$bid", "button with label $label "); }			
+			addButton([$bid, $label,[$winScale*($ps*2-1),$winScale*$l*4],[$winScale*($len*2+3),$winScale*4], \&{"main::btn".$bid++}]);
 			$line=~s/(\{([^}]*)\})/" " x length($1)/e;     #remove buttons replacing with spaces
 		}
 		while ($line=~m/(\[([^\]]+)\])/g){   # text ctrls are made from [ default text ] 
@@ -171,11 +187,12 @@ sub convert{
 		  print $deb."\n";
 	}
   }
-}	
+}
 
+1;
 =head1 GUIDeFATE
 
-GUIDeFATE  -  Grapghical User Interface Design From A Text Editor
+GUIDeFATE  -  Graphical User Interface Design From A Text Editor
 
 =head1 SYNOPSIS
 
@@ -197,14 +214,14 @@ GUIDeFATE  -  Grapghical User Interface Design From A Text Editor
 
     END
 
-    GUIDeFATE::convert($window);
-    my $gui=GUIDeFATE->new();
-    $frame->{stattext21}->SetForegroundColour( Wx::Colour->new(255, 0, 0) );
+    my $gui=GUIDeFATE->new($window);
+    $frame=$gui->getFrame;
     $gui->MainLoop;
 
 =head1 REQUIRES
 
-Perl5.8.8, Exporter, Wx, Wx::Perl::Imagick
+Perl5.8.8, Exporter, Wx, Wx::Perl::Imagick (for Wx interface)
+Perl5.8.8, Exporter, Tk, Image::Imagick, Tk::JPEG, MIME::Base64 (for Tk interface)
 
 =head1 EXPORTS
 
@@ -222,13 +239,13 @@ as a string to GUIDeFATE and this is transformed into an Interactive Interface.
 
 =over 4
 
-=item GUIDeFATE::convert($window, $options)
+=item my $gui=GUIDeFATE->new($window, $backend, $options);
 
-Extracts dimensions and wdigets in a window from the etxual representation
+Extracts dimensions and wdigets in a window from the textual representation
 
-=item new GUIDeFATE("wx")
+=item my $frame=$gui->getFrame;
 
-Creates and returns a new Application using a previously converted frame
+Returns reference to the frame for both abstracted and backend specific functions 
 
 =back
 
@@ -238,8 +255,6 @@ Saif Ahmed, SAIFTYNET { at } gmail.com
 
 =head1 SEE ALSO
 
-Wx, Wx::Perl::Imagick
+L<Wx>, L<Tk>, L<Image::Magick>, L<Wx::Perl::Magick>,
 
 =cut
-
-1;
